
.def-Text
{
 color: #000000;
 background-color: #FFFFFF;
}

.def-HorzCross
{
 color: #000000;
 background-color: #e1ebe0;
}

.def-VertCross
{
 color: #000000;
 background-color: #e1ebe0;
}

.def-Number
{
 color: #800000;
}

.def-String
{
 color: #0000e6;
}

.html-htmlString
{
 color: #000000;
}

.html-htmlParam
{
 color: #000000;
 font-weight: bold; 
}

.def-Character
{
 color: #000080;
}

.def-Comment
{
 color: #008000;
}

.def-Symbol
{
 color: #0000FF;
}

.def-Operator
{
 font-weight: bold; 
 color: #0000FF;
}

.def-Keyword
{
 color: #0000FF;
 font-weight: bold; 
}

.def-KeywordStrong
{
 color: #000088;
 font-weight: bold; 
}

.def-Function
{
 color: #000080;
 font-weight: bold; 
}

.def-Register
{
 color: #000080;
}

.def-Constant
{
 color: #808080;
 font-weight: bold; 
}

.def-Var
{
 color: #800080;
 font-weight: bold; 
}

.def-VarStrong
{
 color: #007997;
}

.def-Identifier
{
 color: #005fd2;
}

.def-BooleanConstant
{
 color: #0f4d75;
}

.def-Directive
{
 color: #004a43;
}

.def-Parameter
{
 color: #074726;
}

.def-Tag
{
 color: #000080;
}

.def-OpenTag
{
 color: #000080;
}

.def-CloseTag
{
 color: #000080;
}

.def-Label
{
 color: #e34adc;
}

.def-LabelStrong
{
 color: #000000;
 background-color: #a8a800;
}

.def-Insertion
{
}

.def-InsertionStart
{
 background-color: #C0C0C0;
 font-weight: bold; 
}

.def-InsertionEnd
{
 background-color: #C0C0C0;
 font-weight: bold; 
}

.def-Error
{
 color: #ffffff;
 background-color: #dd0000;
 font-weight: bold; 
 font-style: italic; 
}

.def-ErrorText
{
 color: #ee00ee;
}

.def-TODO
{
 color: #ffffff;
 background-color: #808000;
}

.def-Debug
{
 color: #80abfd;
 background-color: #007084;
}

.def-Path
{
 color: #40015a;
}

.def-URL
{
 color: #5555DD;
}

.def-EMail
{
 color: #7144c4;
}

.def-Date
{
 color: #009797;
}

.def-Time
{
 color: #8745a0;
}

.def-PairStart
{
 color: #AAFFFF;
}

.def-PairEnd
{
 color: #AAFFFF;
}
