
.def-Text
{
 color: #000000;
 background-color: #ffffff;
}

.def-HorzCross
{
 color: #000000;
 background-color: #BBBBBB;
}

.def-VertCross
{
 color: #000000;
 background-color: #BBBBBB;
}

.def-Number
{
 color: #2e2e2e;
}

.def-NumberDec
{
 color: #2e2e2e;
}

.def-NumberHex
{
 color: #2a2a2a;
}

.def-NumberBin
{
 color: #1e1e1e;
}

.def-NumberOct
{
 color: #2e2e2e;
}

.def-NumberFloat
{
 color: #2a2a2a;
}

.def-NumberSuffix
{
 color: #222222;
}

.def-String
{
 color: #4c4c4c;
}

.def-StringContent
{
 color: #7d7d7d;
}

.def-StringEdge
{
 color: #2a2a2a;
}

.def-CharacterContent
{
 color: #444444;
}

.def-Comment
{
 color: #696969;
}

.def-CommentContent
{
 color: #868686;
}

.def-CommentDoc
{
 color: #afafaf;
}

.def-Symbol
{
 color: #555555;
}

.def-SymbolStrong
{
 color: #555555;
}

.def-Prefix
{
 color: #939393;
}

.def-PrefixStrong
{
 color: #3e3e3e;
}

.def-Operator
{
 color: #939393;
}

.def-Keyword
{
 color: #575757;
 font-weight: bold; 
}

.def-KeywordStrong
{
 color: #8e8e8e;
 font-weight: bold; 
}

.def-Function
{
}

.def-Register
{
 color: #2a2a2a;
}

.def-Constant
{
 color: #404040;
}

.def-Var
{
}

.def-VarStrong
{
 color: #3e3e3e;
}

.def-Identifier
{
 color: #656565;
}

.def-Directive
{
 color: #2f2f2f;
}

.def-Param
{
 color: #262626;
}

.def-Tag
{
 color: #2a2a2a;
}

.def-OpenTag
{
 color: #545454;
}

.def-CloseTag
{
 color: #545454;
}

.def-Label
{
 color: #adadad;
}

.def-LabelStrong
{
 color: #000000;
 background-color: #707070;
}

.def-Insertion
{
 color: #000000;
 background-color: #e0e0e0;
}

.def-InsertionStart
{
 color: #2a2a2a;
 background-color: #e0e0e0;
}

.def-InsertionEnd
{
 color: #2a2a2a;
 background-color: #e0e0e0;
}

.def-Error
{
 color: #ffffff;
 background-color: #494949;
 font-weight: bold; 
}

.def-ErrorText
{
 color: #9e9e9e;
}

.def-TODO
{
 color: #ffffff;
 background-color: #555555;
 font-weight: bold; 
}

.def-Debug
{
 color: #b8b8b8;
 background-color: #515151;
 font-weight: bold; 
}

.def-Path
{
 color: #333333;
}

.def-URL
{
 color: #444444;
}

.def-EMail
{
 color: #676767;
}

.def-Date
{
 color: #646464;
}

.def-Time
{
 color: #797979;
}

.def-PairStart
{
 color: #333333;
}

.def-PairEnd
{
 color: #333333;
}
